/* Blinker
   Copyright 2011-2019 Stefan Schuermans <stefan@blinkenarea.org>
   Copyleft GNU public license - http://www.gnu.org/copyleft/gpl.html
   a blinkenarea.org project */

#ifndef BLINKER_PONG_H
#define BLINKER_PONG_H

#include <string>
#include <vector>

#include <BlinkenLib/BlinkenFrame.h>

#include "Color.h"
#include "ColorFile.h"
#include "File.h"
#include "Format.h"
#include "FormatFile.h"
#include "Game.h"
#include "Mgrs.h"
#include "Module.h"
#include "OutStreamFile.h"

namespace Blinker {

/// pong game
class Pong: public Game
{
public:
  /**
   * @brief constructor
   * @param[in] name module name
   * @param[in] mgrs managers
   * @param[in] dirBase base directory
   */
  Pong(const std::string &name, Mgrs &mgrs, const Directory &dirBase);

  /// virtual destructor
  virtual ~Pong();

private:
  /// copy constructor disabled
  Pong(const Pong &that);

  /// assignment operator disabled
  const Pong & operator=(const Pong &that);

public:
  /// check for update of configuration (derived game), return true on update
  virtual bool updateConfigGame();

protected:
  /// re-initialize game (e.g. due to config change)
  virtual void reinitialize();

  /// redraw current game image, expected to call sendFrame() at end
  virtual void redraw();

protected:
  ColorFile     m_fileBallColor; ///< color file for ball color
  ColorData     m_ballColor;     ///< ball color
}; // class Canvas

} // namespace Blinker

#endif // #ifndef BLINKER_PONG_H

